==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/turtle/dialogs_fr.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Est-ce que tu peux la voir ? Ce doit être la tortue télépathique.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Oui, c'est bien ça. La tortue télépathique.")


dialogId("zel-m-fotky0", "font_small", "Well, I don`t know. Judging from those photos, it could be it.")
dialogStr("Et bien je ne sais pas. A en juger par ces photos, ce pourrait être elle.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Je ne suis pas sûre... Et à propos de ses pouvoirs télépathiques.")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Dans tous les cas nous devons la sortir de la pièce.")


dialogId("zel-v-zmistnosti1", "font_big", "Let`s take out that turtle.")
dialogStr("Faisons sortir cette tortue.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Que fais-tu ?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Qu'as-tu fait ?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Qu'est-ce que ça veut dire ?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Où est-ce que tu nages ?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Qu'est-ce que ça veut dire ?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Qu'est-ce qui t'arrive ?")


dialogId("zel-m-nevim0", "font_small", "I don`t know...")
dialogStr("Je ne sais pas...")


dialogId("zel-m-nevim1", "font_small", "I can`t realize...")
dialogStr("Je ne me rends pas compte...")


dialogId("zel-v-nevim0", "font_big", "I don`t know what`s happening to me...")
dialogStr("Je ne sais pas ce qui m'arrive...")


dialogId("zel-v-nevim1", "font_big", "I didn`t want to...")
dialogStr("Je ne voulais pas...")


dialogId("zel-v-cosedeje", "font_big", "What`s happening to us?")
dialogStr("Qu'est-ce qui nous arrive ?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Se pourrait-il ?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("C'est à cause de cette tortue !")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("Ce doit être cette tortue !")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Ainsi il n'y a plus de doute possible maintenant - c'est elle. Celle que nous recherchons !")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Sans aucun doute, c'est la tortue que nous recherchons !")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Cette brute !")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Arrête ça, démon !")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("C'est la goutte qui fait déborder le vase !")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Est-ce que tu te reconnais toi-même ?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tant de formes bizarres ne se trouve que dans un récif de corail.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature`s wonders.")
dialogStr("Ces coraux sont des merveilles de Mère Nature.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("D'où peuvent bien venir tant de formes étranges ?")


dialogId("zel-m-jednoduse", "font_small", "It`s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Facile - Les créateurs ont conçu d'épineux problèmes et ont laissé les artistes les dessiner.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Notre but est de faire sortir cette tortue.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/turtle/dialogs_fr.lua <==

dialogId("zel-v-zelva0", "font_big", "Can you see it? This must be that telepathic turtle.")
dialogStr("Est-ce que tu peux la voir ? Ce doit être la tortue télépathique.")


dialogId("zel-v-zelva1", "font_big", "Yes, this is it. The telepathic turtle.")
dialogStr("Oui, c'est bien ça. La tortue télépathique.")


dialogId("zel-m-fotky0", "font_small", "Well, I don’t know. Judging from those photos, it could be it.")
dialogStr("Et bien je ne sais pas. A en juger par ces photos, ce pourrait être elle.")


dialogId("zel-m-fotky1", "font_small", "I am not sure... what about those telepathic powers?")
dialogStr("Je ne suis pas sûre... Et à propos de ses pouvoirs télépathiques.")


dialogId("zel-v-zmistnosti0", "font_big", "In any case we have to get it out of the room.")
dialogStr("Dans tous les cas nous devons la sortir de la pièce.")


dialogId("zel-v-zmistnosti1", "font_big", "Let’s take out that turtle.")
dialogStr("Faisons sortir cette tortue.")


dialogId("zel-m-coto0", "font_small", "What are you doing?")
dialogStr("Que fais-tu ?")


dialogId("zel-m-coto1", "font_small", "What have you done?")
dialogStr("Qu'as-tu fait ?")


dialogId("zel-m-coto2", "font_small", "What is it supposed to mean?")
dialogStr("Qu'est-ce que c'est censé vouloir dire ?")


dialogId("zel-v-coto0", "font_big", "Where are you swimming?")
dialogStr("Où est-ce que tu nages ?")


dialogId("zel-v-coto1", "font_big", "What should it mean?")
dialogStr("Qu'est-ce que ça devrait signifier ?")


dialogId("zel-v-coto2", "font_big", "What happened to you?")
dialogStr("Qu'est-ce qui t'arrive ?")


dialogId("zel-m-nevim0", "font_small", "I don’t know...")
dialogStr("Je ne sais pas...")


dialogId("zel-m-nevim1", "font_small", "I can’t realize...")
dialogStr("Je ne me rends pas compte...")


dialogId("zel-v-nevim0", "font_big", "I don’t know what’s happening to me...")
dialogStr("Je ne sais pas ce qui m'arrive...")


dialogId("zel-v-nevim1", "font_big", "I didn’t want to...")
dialogStr("Je ne voulais pas...")


dialogId("zel-v-cosedeje", "font_big", "What’s happening to us?")
dialogStr("Qu'est-ce qui nous arrive ?")


dialogId("zel-m-cimtoje", "font_small", "What can it mean?")
dialogStr("Qu'est-ce que ça peut vouloir dire ?")


dialogId("zel-m-tazelva", "font_small", "This must be that turtle!")
dialogStr("C'est sans doute à cause de cette tortue !")


dialogId("zel-v-tazelva", "font_big", "This must be that turtle!")
dialogStr("C'est sans doute à cause cette tortue !")


dialogId("zel-m-jasne", "font_small", "So there can be no doubts now - this is it. The one we are looking for!")
dialogStr("Ainsi il n'y a plus de doute possible maintenant - c'est elle. Celle que nous recherchons !")


dialogId("zel-v-pochyby", "font_big", "Doubtless, this is the turtle we are looking for!")
dialogStr("Sans aucun doute, c'est la tortue que nous recherchons !")


dialogId("zel-m-potvora0", "font_small", "That beast!")
dialogStr("Quelle brute !")


dialogId("zel-m-potvora1", "font_small", "Stop it, you devil!")
dialogStr("Arrête ça, démon !")


dialogId("zel-v-stacit0", "font_big", "Enough is enough!")
dialogStr("C'est la goutte qui fait déborder le vase !")


dialogId("zel-v-stacit1", "font_big", "Are you enjoying yourself?")
dialogStr("Est-ce que tu t'amuses bien ?")


dialogId("zel-v-bizarni", "font_big", "So many bizarre shapes can only be found in a coral reef.")
dialogStr("Tant de formes bizarres ne se trouve que dans un récif de corail.")


dialogId("zel-m-priroda", "font_small", "These corals are Mother Nature’s wonders.")
dialogStr("Ces coraux sont des merveilles de Mère Nature.")


dialogId("zel-v-tvary", "font_big", "Where do so many bizarre shapes come from?")
dialogStr("D'où peuvent bien venir tant de formes étranges ?")


dialogId("zel-m-jednoduse", "font_small", "It’s easy - designers create tricky problems and leave the drawing to the graphic artists.")
dialogStr("Facile - Les créateurs ont conçu d'épineux problèmes et ont laissé les artistes les dessiner.")


dialogId("zel-v-ukol", "font_big", "Our goal in this room is to get out that turtle.")
dialogStr("Notre but est de faire sortir de cette tortue.")
